@@ -1,6 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2019 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -171,7 +172,7 @@ from pyglet.text import runlist
 
 from pyglet.font.base import _grapheme_break
 
-_is_pyglet_docgen = hasattr(sys, 'is_pyglet_docgen') and sys.is_pyglet_docgen
+_is_pyglet_doc_run = hasattr(sys, "is_pyglet_doc_run") and sys.is_pyglet_doc_run
 
 _distance_re = re.compile(r'([-0-9.]+)([a-zA-Z]+)')
 
@@ -970,6 +971,19 @@ class TextLayout(object):
             self._create_vertex_lists(left + line.x, top + line.y,
                                       line.start, line.boxes, context)
 
+    def _update_color(self):
+        colors_iter = self._document.get_style_runs('color')
+        colors = []
+        for start, end, color in colors_iter.ranges(0, colors_iter.length):
+            if color is None:
+                color = (0, 0, 0, 255)
+            colors.extend(color * ((end - start) * 4))
+
+        start = 0
+        for _vertex_list in self._vertex_lists:
+            _vertex_list.colors = colors[start:start+len(_vertex_list.colors)]
+            start += len(_vertex_list.colors)
+
     def _get_left(self):
         if self._multiline:
             width = self._width if self._wrap_lines else self.content_width
@@ -1044,7 +1058,10 @@ class TextLayout(object):
         The event handler is bound by the text layout; there is no need for
         applications to interact with this method.
         """
-        self._init_document()
+        if len(attributes) == 1 and 'color' in attributes.keys():
+            self._update_color()
+        else:
+            self._init_document()
 
     def _get_glyphs(self):
         glyphs = []
@@ -1263,12 +1280,18 @@ class TextLayout(object):
                             if new_paragraph:
                                 line.paragraph_end = True
                             yield line
-                            line = _Line(next_start)
-                            line.align = align_iterator[next_start]
-                            line.margin_left = self._parse_distance(
-                                margin_left_iterator[next_start])
-                            line.margin_right = self._parse_distance(
-                                margin_right_iterator[next_start])
+                            try:
+                                line = _Line(next_start)
+                                line.align = align_iterator[next_start]
+                                line.margin_left = self._parse_distance(
+                                    margin_left_iterator[next_start])
+                                line.margin_right = self._parse_distance(
+                                    margin_right_iterator[next_start])
+                            except IndexError:
+                                # XXX This used to throw StopIteration in some cases, causing the
+                                # final part of this method not to be executed. Refactoring
+                                # required to fix this
+                                return
                             if new_paragraph:
                                 line.paragraph_begin = True
 
@@ -2400,6 +2423,9 @@ class IncrementalTextLayout(ScrollableTextLayout, event.EventDispatcher):
         line = self.lines[line]
         x -= self.top_group.translate_x
 
+        if x < line.x:
+            return line.start
+
         position = line.start
         last_glyph_x = line.x
         for box in line.boxes:
@@ -2452,7 +2478,7 @@ class IncrementalTextLayout(ScrollableTextLayout, event.EventDispatcher):
                       self.content_width > self.width):
             self.view_x = x - self.width + 10
 
-    if _is_pyglet_docgen:
+    if _is_pyglet_doc_run:
         def on_layout_update(self):
             """Some or all of the layout text was reflowed.
 
